<?php
session_start();

try {
    $dsn = 'sqlite:/Users/rileykate/Desktop/CS480/leaderboard.db';
    $pdo = new PDO($dsn);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
} catch (PDOException $e) {
    die("Could not connect to the database: " . $e->getMessage());
}

// Fetch leaderboard data from database
try {
    $query = "SELECT id, player_name, score, victory_message FROM leaderboard_table ORDER BY score DESC LIMIT 10";
    $stmt = $pdo->query($query);
    $leaderboard = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    die("Error fetching leaderboard: " . $e->getMessage());
}

// Determine current player rank
$current_player = $_SESSION['username'] ?? null;
$current_score = $_SESSION['score'] ?? null;
$player_rank = null;

if ($current_player && $current_score) {
    foreach ($leaderboard as $index => $entry) {
        if ($entry['player_name'] === $current_player && $entry['score'] === $current_score) {
            $player_rank = $index + 1;
            break;
        }
    }
}

// Adds a victory message to the database for the session player
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['victory_message'], $_POST['id'])) {
    $victory_message = trim($_POST['victory_message']);
    $id = intval($_POST['id']);

    if ($player_rank !== null && $player_rank <= 3) {
        try {
            $updateQuery = "UPDATE leaderboard_table SET victory_message = :victory_message WHERE id = :id";
            $stmt = $pdo->prepare($updateQuery);
            $stmt->bindParam(':victory_message', $victory_message);
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);
            $stmt->execute();
        } catch (PDOException $e) {
            die("Error updating victory message: " . $e->getMessage());
        }

        header("Location: " . $_SERVER['PHP_SELF']);
        exit;
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <link rel="icon" type="image/x-icon" href="/images/favicon.png">
    <title>Leaderboard | SPS</title>
    <link rel="stylesheet" href="style.css">
</head>
<body>
<form method="post" action="logout.php">
    <button type="submit" class="rounded-button sticky"><img src="/images/home.png" class="icon"></button>
</form>
<div class="center"><img src="/images/logo.png" class="homeLogo"></div>
<div class="centeredContainer">
    <h1 class="title">Leaderboard</h1>

    <!-- Victory Message Input for Top 3 Players -->
    <?php if ($player_rank !== null && $player_rank <= 3): ?>
        <form method="post">
            <h2 class="centeredText"> Congrats! You made it onto the podium!</h2>
            <label for="victory_message" class="buttonLabel mobile">Enter your victory message:</label><br>
            <input type="text" id="victory_message" name="victory_message" size="50" class="styled-input" placeholder="victory message" required>
            <input type="hidden" name="id" value="<?= htmlspecialchars($leaderboard[$player_rank - 1]['id']) ?>">
            <button type="submit" class="rounded-button">Submit</button>
        </form>
    <?php endif; ?>

    <!-- Display the leaderboard -->
    <table class="border zebra-table">
        <thead>
        <tr>
            <th>Rank</th>
            <th>Player Name</th>
            <th>Score</th>
            <th>Victory Message</th>
        </tr>
        </thead>
        <tbody>
        <?php foreach ($leaderboard as $index => $entry): ?>
            <tr>
                <td><?= $index + 1 ?></td>
                <td><?= htmlspecialchars($entry['player_name']) ?></td>
                <td><?= htmlspecialchars($entry['score']) ?></td>
                <td><?= htmlspecialchars($entry['victory_message'] ?? '') ?></td>
            </tr>
        <?php endforeach; ?>
        </tbody>
    </table>

    <form method="post" action="logout.php">
        <button type="submit" class="rounded-button">Play Again</button>
    </form>
</div>
</body>
</html>
