<?php

session_start();

// Connect to the database
try {
    $dsn = 'sqlite:/Users/rileykate/Desktop/CS480/leaderboard.db';
    $pdo = new PDO($dsn);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
} catch (PDOException $e) {
    die("Could not connect to the database: " . $e->getMessage());
}

// API URL for trivia questions
$api_url = "https://opentdb.com/api.php?amount=1&type=multiple";
?>

<?php
// Get a new question
if (!isset($_SESSION['current_question']) || isset($_POST['next_question'])) {
    $response = file_get_contents($api_url);
    $data = json_decode($response, true);

    if ($response && $data['response_code'] === 0) {
        $_SESSION['current_question'] = htmlspecialchars_decode($data['results'][0]['question']);
        $_SESSION['correct_answer'] = htmlspecialchars_decode($data['results'][0]['correct_answer']);
        $_SESSION['all_answers'] = array_map('htmlspecialchars_decode', $data['results'][0]['incorrect_answers']);
        $_SESSION['all_answers'][] = $_SESSION['correct_answer'];
        shuffle($_SESSION['all_answers']);
    } else {
        die("Error: Unable to fetch trivia question. Please try again later.");
    }
}

if (!isset($_SESSION['score'])) {
    $_SESSION['score'] = 0;
}

if (isset($_POST['next_question'])) {
    $_SESSION['feedback_shown'] = false;
}
?>

<?php
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['answer'])) {
    $user_answer = $_POST['answer'];
    $correct_answer = $_SESSION['correct_answer'];

    if (trim($user_answer) === trim($correct_answer)) {
        $_SESSION['score']++;
        $feedback = "Correct!";
    } else {
        $feedback = "Incorrect. The correct answer was: $correct_answer";
    }

    $_SESSION['feedback_shown'] = true;

    $show_next_button = true;
}

if (isset($_GET['timeout']) && $_GET['timeout'] === 'true') {
    $feedback = "Time's up! The correct answer was: " . htmlspecialchars($_SESSION['correct_answer']);
    echo json_encode([
        'feedback' => $feedback,
        'score' => $_SESSION['score']
    ]);
    $show_next_button = true;
    exit;
}

if (isset($_POST['end_game'])) {
    if (isset($_SESSION['username']) && isset($_SESSION['score'])) {
        try {
            $player_name = $_SESSION['username'];
            $score = $_SESSION['score'];

            $insertQuery = "INSERT INTO leaderboard_table (player_name, score) VALUES (:player_name, :score)";
            $stmt = $pdo->prepare($insertQuery);
            $stmt->bindParam(':player_name', $player_name);
            $stmt->bindParam(':score', $score);
            $stmt->execute();
        } catch (PDOException $e) {
            die("Error inserting score into the database: " . $e->getMessage());
        }
    }
    header("Location: leaderboard.php");
    exit;
}

if (isset($_POST['reset_game'])) {
    session_destroy();
    header("Location: " . $_SERVER['PHP_SELF']);
    exit;
}
?>

<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Smarty Pants Showdown</title>
    <link rel="icon" type="image/x-icon" href="/images/favicon.png">
    <link rel="stylesheet" href="style.css">
    <link rel="preconnect" href="https://fonts.googleapis.com">
    <link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
    <link href="https://fonts.googleapis.com/css2?family=Anton+SC&display=swap" rel="stylesheet">
</head>

<body>
<div class="flex">
    <form method="post" action="logout.php" onsubmit="return confirm('Are you sure you want to quit? Your score will not be saved.');">
        <button type="submit" class="rounded-button sticky">
            <img src="/images/home.png" class="icon">
        </button>
    </form>
    <div class="timer-holder sticky left">
        <p id="timer" style="font-weight: bold; color: #b6d874;">Time remaining: 60 seconds</p>
    </div>
</div>
<div class="center">
    <img src="/images/logo.png" class="gamePageLogo">
</div>
<div class="centeredContainer">
    <h2>Question:</h2>

    <p class="centeredContainer">
        <?= html_entity_decode($_SESSION['current_question']) ?>
    </p><br>
    <form id="trivia-form" method="post" class="centeredText">
        <?php foreach ($_SESSION['all_answers'] as $answer) : ?>
            <div>
                <input type="radio" id="<?= html_entity_decode($answer) ?>" name="answer" value="<?= html_entity_decode($answer) ?>" class="answerChoice" required>
                <label for="<?= html_entity_decode($answer) ?>" class="answerChoice"> <?= html_entity_decode($answer) ?></label>
                <br><br>
            </div>
        <?php endforeach; ?>
        <button type="submit" class="rounded-button">Submit</button>
    </form>
    <?php if (isset($feedback)) : ?>
        <p id="feedback"><strong><?= html_entity_decode($feedback) ?></strong></p>
    <?php else : ?>
        <p id="feedback"></p>
    <?php endif; ?>
    <?php if ((isset($show_next_button) && $show_next_button)) : ?>
        <form method="post">
            <button type="submit" name="next_question" class="rounded-button">Next Question</button>
        </form>
    <?php endif; ?>
    <div class="moveUp">
        <div class="moveRight">
            <h2>Score: <span id="score"> <?= htmlspecialchars($_SESSION['score']) ?> </span></h2>
        </div>
        <form method="post">
            <button type="submit" name="end_game" class="rounded-button">End Game</button>
        </form>
    </div>
    <script>
        let timeLeft = 60;
        const timerElement = document.getElementById('timer');
        const triviaForm = document.getElementById('trivia-form');
        const feedbackElement = document.getElementById('feedback');
        const timerHolder = document.querySelector('.timer-holder');

        function startTimer() {
            timeLeft = 60;

            if (timerHolder) {
                timerHolder.style.display = "block";
            }

            timerElement.textContent = `Time remaining: ${timeLeft} seconds`;
            timerElement.style.color = "#b6d874";

            if (window.timerInterval) {
                clearInterval(window.timerInterval);
            }

            window.timerInterval = setInterval(() => {
                if (timeLeft > 0) {
                    timeLeft--;
                    timerElement.textContent = `Time remaining: ${timeLeft} seconds`;

                    if (timeLeft <= 10) {
                        timerElement.style.color = "#F26B5A";
                    }
                } else {
                    clearInterval(window.timerInterval);

                    if (timerHolder) {
                        timerHolder.style.display = "none";
                    }

                    if (triviaForm) {
                        triviaForm.style.display = "none";
                    }

                    fetch("trivia_game.php?timeout=true", { method: "GET" })
                        .then(response => response.json())
                        .then(data => {
                            feedbackElement.innerHTML = `<div class="lilSpace"><strong>${data.feedback}</strong></div>`;

                            const nextButton = document.createElement('button');
                            nextButton.type = "submit";
                            nextButton.name = "next_question";
                            nextButton.className = "rounded-button center";
                            nextButton.textContent = "Next Question";

                            const nextForm = document.createElement('form');
                            nextForm.method = "post";
                            nextForm.appendChild(nextButton);
                            nextForm.className = "center";

                            feedbackElement.appendChild(nextForm);
                        })
                        .catch(error => console.error('Error:', error));
                }
            }, 1000);
        }

        if (triviaForm && !<?php echo isset($_SESSION['feedback_shown']) && $_SESSION['feedback_shown'] ? 'true' : 'false'; ?>) {
            startTimer();
        }

        if (<?php echo isset($_SESSION['feedback_shown']) && $_SESSION['feedback_shown'] ? 'true' : 'false'; ?>) {
            if (timerHolder) timerHolder.style.display = "none";
            if (triviaForm) triviaForm.style.display = "none";
        }
    </script>
</div>
</body>

</html>
